Quickstart
----------
The aim of `scope` is to simulate observations of exoplanet atmospheres with ground-based, high-resolution spectroscopy.
Simulating the atmosphere *itself* — performing the radiative transfer calculations to generate a spectrum
that depends on atmospheric properties — is out of scope for `scope`.
